@@ -512,7 +512,8 @@ def generate_ros_distro_diff(track, repository, distro, override_release_reposit
         source = distribution_dict['repositories'][repository].get('source', {})
         if not source and maybe_continue(msg='Would you like to add source information for this repository?'):
             defaults = None
-            info(fmt("@{gf}@!==> @|") + "Looking for a source entry for this repository in a different distribution...")
+            info(fmt("@{gf}@!==> @|") +
+                 "Looking for a source entry for this repository in a different distribution...")
             default_distro, default_source = get_most_recent('source', repository)
             if default_distro is None:
                 warning("No existing source entries found for use as defaults.")
@@ -527,6 +528,14 @@ def generate_ros_distro_diff(track, repository, distro, override_release_reposit
             info("Please enter information which points to the active development branch for this repository.")
             info("This information is used to run continuous integration jobs and for developers to checkout from.")
             source = get_repository_info_from_user('source', defaults)
+
+            if validate_github_url(source['url'], 'source'):
+                info("Since you are on github we can add a job to run your tests on each pull request."
+                     "If you would like to turn this on please see "
+                     "http://wiki.ros.org/buildfarm/Pull%20request%20testing for more information. "
+                     "There is more setup required to setup the hooks correctly. ")
+                if maybe_continue(msg='Would you like to turn on pull request testing?', default='n'):
+                    source['test_pull_requests'] = 'true'
         distribution_dict['repositories'][repository]['source'] = source
 
     # Ask for maintainership information
@@ -765,7 +774,7 @@ def open_pull_request(track, repository, distro, interactive, override_release_r
     # Check if the github user and the base org are the same
     if gh.username == base_org:
         # If it is, then a fork is not necessary
-        head_repo = base_repo
+        head_repo = gh.get_repo(base_org, base_repo)
     else:
         info(fmt("@{bf}@!==> @|@!Checking on GitHub for a fork to make the pull request from..."))
         # It is not, so a fork will be required
